#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-template
version: 2.1.6
id: persistent-template-2.1.6-696af2309e8b2b7d269b843dd09030c3
key: persi_9bUEPeow1YO6pGeKY4A504
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>, Greg Weber <greg@gregweber.info>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Type-safe, non-relational, multi-backend persistence.
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/persistent-template>.
category: Database, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Database.Persist.TH
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
library-dirs: /usr/lib/ghc-7.10.3/site-local/persistent-template-2.1.6
data-dir: /usr/share/arm-linux-ghc-7.10.3/persistent-template-2.1.6
hs-libraries: HSpersistent-template-2.1.6-9bUEPeow1YO6pGeKY4A504
depends:
    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
    aeson-compat-0.3.2.0-725b78f3168d9bafe282f8360603746a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    http-api-data-0.2.2-d85b0db99d6d5995d772ab01cd2ae49e
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    monad-logger-0.3.18-77245c726e2e1fb18d9b7ba72ab04e41
    path-pieces-0.2.1-f62a4ee86afe2692f9fb79d2dd895499
    persistent-2.2.4.1-f7f5136d623755022a88522f150cf471
    tagged-0.8.3-aa128de4449752177a05765fb0ce3959
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
haddock-interfaces: /usr/share/doc/haskell-persistent-template/html/persistent-template.haddock
haddock-html: /usr/share/doc/haskell-persistent-template/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
